@@ -1,10 +1,10 @@
 /*
-  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2019, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -32,10 +32,10 @@ import java.sql.SQLException;
 import java.sql.Types;
 import java.util.Properties;
 
-import testsuite.BaseTestCase;
-
 import com.mysql.jdbc.SQLError;
-import com.mysql.jdbc.log.StandardLogger;
+
+import testsuite.BaseTestCase;
+import testsuite.BufferingLogger;
 
 /**
  * Tests callable statement functionality.
@@ -82,15 +82,14 @@ public class CallableStatementTest extends BaseTestCase {
 
                 executeBatchedStoredProc(this.conn);
 
-                batchedConn = getConnectionWithProps("logger=StandardLogger,rewriteBatchedStatements=true,profileSQL=true");
+                batchedConn = getConnectionWithProps("logger=" + BufferingLogger.class.getName() + ",rewriteBatchedStatements=true,profileSQL=true");
 
-                StringBuffer outBuf = new StringBuffer();
-                StandardLogger.bufferedLog = outBuf;
+                BufferingLogger.startLoggingToBuffer();
                 executeBatchedStoredProc(batchedConn);
-                String[] log = outBuf.toString().split(";");
+                String[] log = BufferingLogger.getBuffer().toString().split(";");
                 assertTrue(log.length > 20);
             } finally {
-                StandardLogger.bufferedLog = null;
+                BufferingLogger.dropBuffer();
 
                 if (batchedConn != null) {
                     batchedConn.close();
@@ -157,41 +156,39 @@ public class CallableStatementTest extends BaseTestCase {
 
             int indexedOutParamToTest = storedProc.getInt(2);
 
-            if (!isRunningOnJdk131()) {
-                int namedOutParamToTest = storedProc.getInt("y");
+            int namedOutParamToTest = storedProc.getInt("y");
 
-                assertTrue("Named and indexed parameter are not the same", indexedOutParamToTest == namedOutParamToTest);
-                assertTrue("Output value not returned correctly", indexedOutParamToTest == 6);
+            assertTrue("Named and indexed parameter are not the same", indexedOutParamToTest == namedOutParamToTest);
+            assertTrue("Output value not returned correctly", indexedOutParamToTest == 6);
 
-                // Start over, using named parameters, this time
-                storedProc.clearParameters();
-                storedProc.setInt("x", 32);
-                storedProc.registerOutParameter("y", Types.INTEGER);
+            // Start over, using named parameters, this time
+            storedProc.clearParameters();
+            storedProc.setInt("x", 32);
+            storedProc.registerOutParameter("y", Types.INTEGER);
 
-                storedProc.execute();
+            storedProc.execute();
 
-                indexedOutParamToTest = storedProc.getInt(2);
-                namedOutParamToTest = storedProc.getInt("y");
+            indexedOutParamToTest = storedProc.getInt(2);
+            namedOutParamToTest = storedProc.getInt("y");
 
-                assertTrue("Named and indexed parameter are not the same", indexedOutParamToTest == namedOutParamToTest);
-                assertTrue("Output value not returned correctly", indexedOutParamToTest == 33);
+            assertTrue("Named and indexed parameter are not the same", indexedOutParamToTest == namedOutParamToTest);
+            assertTrue("Output value not returned correctly", indexedOutParamToTest == 33);
 
-                try {
-                    storedProc.registerOutParameter("x", Types.INTEGER);
-                    assertTrue("Should not be able to register an out parameter on a non-out parameter", true);
-                } catch (SQLException sqlEx) {
-                    if (!SQLError.SQL_STATE_ILLEGAL_ARGUMENT.equals(sqlEx.getSQLState())) {
-                        throw sqlEx;
-                    }
+            try {
+                storedProc.registerOutParameter("x", Types.INTEGER);
+                assertTrue("Should not be able to register an out parameter on a non-out parameter", true);
+            } catch (SQLException sqlEx) {
+                if (!SQLError.SQL_STATE_ILLEGAL_ARGUMENT.equals(sqlEx.getSQLState())) {
+                    throw sqlEx;
                 }
+            }
 
-                try {
-                    storedProc.getInt("x");
-                    assertTrue("Should not be able to retreive an out parameter on a non-out parameter", true);
-                } catch (SQLException sqlEx) {
-                    if (!SQLError.SQL_STATE_COLUMN_NOT_FOUND.equals(sqlEx.getSQLState())) {
-                        throw sqlEx;
-                    }
+            try {
+                storedProc.getInt("x");
+                assertTrue("Should not be able to retreive an out parameter on a non-out parameter", true);
+            } catch (SQLException sqlEx) {
+                if (!SQLError.SQL_STATE_COLUMN_NOT_FOUND.equals(sqlEx.getSQLState())) {
+                    throw sqlEx;
                 }
             }
 
@@ -275,12 +272,12 @@ public class CallableStatementTest extends BaseTestCase {
 
         if (versionMeetsMinimum(5, 0)) {
 
-            @SuppressWarnings("unused")
             CallableStatement storedProc = null;
 
             createProcedure("testSpParse", "(IN FOO VARCHAR(15))\nBEGIN\nSELECT 1;\nend\n");
 
             storedProc = this.conn.prepareCall("{call testSpParse()}");
+            storedProc.close();
 
         }
     }
@@ -312,10 +309,6 @@ public class CallableStatementTest extends BaseTestCase {
      *             if an error occurs.
      */
     public void testSPCache() throws Exception {
-        if (isRunningOnJdk131()) {
-            return; // no support for LRUCache
-        }
-
         if (versionMeetsMinimum(5, 0)) {
 
             CallableStatement storedProc = null;
@@ -437,13 +430,11 @@ public class CallableStatementTest extends BaseTestCase {
             createProcedure("bar", "(x char(16), y int, z DECIMAL(10)) insert into test.t1 values (x, y);");
             cstmt = this.conn.prepareCall("{CALL bar(?, ?, ?)}");
 
-            if (!isRunningOnJdk131()) {
-                ParameterMetaData md = cstmt.getParameterMetaData();
-                assertEquals(3, md.getParameterCount());
-                assertEquals(Types.CHAR, md.getParameterType(1));
-                assertEquals(Types.INTEGER, md.getParameterType(2));
-                assertEquals(Types.DECIMAL, md.getParameterType(3));
-            }
+            ParameterMetaData md = cstmt.getParameterMetaData();
+            assertEquals(3, md.getParameterCount());
+            assertEquals(Types.CHAR, md.getParameterType(1));
+            assertEquals(Types.INTEGER, md.getParameterType(2));
+            assertEquals(Types.DECIMAL, md.getParameterType(3));
 
             createProcedure("p", "() label1: WHILE @a=0 DO SET @a=1; END WHILE");
             this.conn.prepareCall("{CALL p()}");
@@ -451,10 +442,8 @@ public class CallableStatementTest extends BaseTestCase {
             createFunction("f", "() RETURNS INT NO SQL return 1; ");
             cstmt = this.conn.prepareCall("{? = CALL f()}");
 
-            if (!isRunningOnJdk131()) {
-                ParameterMetaData md = cstmt.getParameterMetaData();
-                assertEquals(Types.INTEGER, md.getParameterType(1));
-            }
+            md = cstmt.getParameterMetaData();
+            assertEquals(Types.INTEGER, md.getParameterType(1));
         } finally {
             if (cstmt != null) {
                 cstmt.close();
