@@ -1,10 +1,10 @@
 /*
-  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2018, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -42,19 +42,20 @@ import java.sql.Time;
 import java.sql.Timestamp;
 import java.sql.Types;
 import java.text.SimpleDateFormat;
-import java.util.Locale;
 import java.util.Properties;
 
-import testsuite.BaseTestCase;
-
 import com.mysql.jdbc.CharsetMapping;
 import com.mysql.jdbc.MySQLConnection;
 import com.mysql.jdbc.NotImplemented;
 import com.mysql.jdbc.ParameterBindings;
 import com.mysql.jdbc.SQLError;
 import com.mysql.jdbc.StringUtils;
+import com.mysql.jdbc.TimeUtil;
 import com.mysql.jdbc.exceptions.MySQLStatementCancelledException;
 import com.mysql.jdbc.exceptions.MySQLTimeoutException;
+import com.mysql.jdbc.interceptors.ServerStatusDiffInterceptor;
+
+import testsuite.BaseTestCase;
 
 public class StatementsTest extends BaseTestCase {
     private static final int MAX_COLUMN_LENGTH = 255;
@@ -89,24 +90,24 @@ public class StatementsTest extends BaseTestCase {
 
         this.stmt.executeUpdate("DROP TABLE IF EXISTS statement_batch_test");
 
-        this.stmt
-                .executeUpdate("CREATE TABLE statement_test (id int not null primary key auto_increment, strdata1 varchar(255) not null, strdata2 varchar(255))");
+        this.stmt.executeUpdate(
+                "CREATE TABLE statement_test (id int not null primary key auto_increment, strdata1 varchar(255) not null, strdata2 varchar(255))");
 
         try {
             this.stmt.executeUpdate("CREATE TABLE statement_batch_test (id int not null primary key auto_increment, "
                     + "strdata1 varchar(255) not null, strdata2 varchar(255), UNIQUE INDEX (strdata1))");
         } catch (SQLException sqlEx) {
             if (sqlEx.getMessage().indexOf("max key length") != -1) {
-                createTable("statement_batch_test", "(id int not null primary key auto_increment, strdata1 varchar(175) not null, strdata2 varchar(175), "
-                        + "UNIQUE INDEX (strdata1))");
+                createTable("statement_batch_test",
+                        "(id int not null primary key auto_increment, strdata1 varchar(175) not null, strdata2 varchar(175), " + "UNIQUE INDEX (strdata1))");
             }
         }
 
         for (int i = 6; i < MAX_COLUMNS_TO_TEST; i += STEP) {
             this.stmt.executeUpdate("DROP TABLE IF EXISTS statement_col_test_" + i);
 
-            StringBuffer insertBuf = new StringBuffer("INSERT INTO statement_col_test_");
-            StringBuffer stmtBuf = new StringBuffer("CREATE TABLE IF NOT EXISTS statement_col_test_");
+            StringBuilder insertBuf = new StringBuilder("INSERT INTO statement_col_test_");
+            StringBuilder stmtBuf = new StringBuilder("CREATE TABLE IF NOT EXISTS statement_col_test_");
             stmtBuf.append(i);
             insertBuf.append(i);
             stmtBuf.append(" (");
@@ -155,7 +156,7 @@ public class StatementsTest extends BaseTestCase {
             this.stmt.executeUpdate("DROP TABLE statement_test");
 
             for (int i = 6; i < MAX_COLUMNS_TO_TEST; i += STEP) {
-                StringBuffer stmtBuf = new StringBuffer("DROP TABLE IF EXISTS statement_col_test_");
+                StringBuilder stmtBuf = new StringBuilder("DROP TABLE IF EXISTS statement_col_test_");
                 stmtBuf.append(i);
                 this.stmt.executeUpdate(stmtBuf.toString());
             }
@@ -249,49 +250,47 @@ public class StatementsTest extends BaseTestCase {
     }
 
     public void testAutoIncrement() throws SQLException {
-        if (!isRunningOnJdk131()) {
-            try {
-                this.stmt.setFetchSize(Integer.MIN_VALUE);
+        try {
+            this.stmt.setFetchSize(Integer.MIN_VALUE);
 
-                this.stmt.executeUpdate("INSERT INTO statement_test (strdata1) values ('blah')", Statement.RETURN_GENERATED_KEYS);
+            this.stmt.executeUpdate("INSERT INTO statement_test (strdata1) values ('blah')", Statement.RETURN_GENERATED_KEYS);
 
-                int autoIncKeyFromApi = -1;
-                this.rs = this.stmt.getGeneratedKeys();
+            int autoIncKeyFromApi = -1;
+            this.rs = this.stmt.getGeneratedKeys();
 
-                if (this.rs.next()) {
-                    autoIncKeyFromApi = this.rs.getInt(1);
-                } else {
-                    fail("Failed to retrieve AUTO_INCREMENT using Statement.getGeneratedKeys()");
-                }
-
-                this.rs.close();
-
-                int autoIncKeyFromFunc = -1;
-                this.rs = this.stmt.executeQuery("SELECT LAST_INSERT_ID()");
-
-                if (this.rs.next()) {
-                    autoIncKeyFromFunc = this.rs.getInt(1);
-                } else {
-                    fail("Failed to retrieve AUTO_INCREMENT using LAST_INSERT_ID()");
-                }
-
-                if ((autoIncKeyFromApi != -1) && (autoIncKeyFromFunc != -1)) {
-                    assertTrue("Key retrieved from API (" + autoIncKeyFromApi + ") does not match key retrieved from LAST_INSERT_ID() " + autoIncKeyFromFunc
-                            + ") function", autoIncKeyFromApi == autoIncKeyFromFunc);
-                } else {
-                    fail("AutoIncrement keys were '0'");
-                }
-            } finally {
-                if (this.rs != null) {
-                    try {
-                        this.rs.close();
-                    } catch (Exception ex) {
-                        // ignore
-                    }
-                }
-
-                this.rs = null;
+            if (this.rs.next()) {
+                autoIncKeyFromApi = this.rs.getInt(1);
+            } else {
+                fail("Failed to retrieve AUTO_INCREMENT using Statement.getGeneratedKeys()");
             }
+
+            this.rs.close();
+
+            int autoIncKeyFromFunc = -1;
+            this.rs = this.stmt.executeQuery("SELECT LAST_INSERT_ID()");
+
+            if (this.rs.next()) {
+                autoIncKeyFromFunc = this.rs.getInt(1);
+            } else {
+                fail("Failed to retrieve AUTO_INCREMENT using LAST_INSERT_ID()");
+            }
+
+            if ((autoIncKeyFromApi != -1) && (autoIncKeyFromFunc != -1)) {
+                assertTrue("Key retrieved from API (" + autoIncKeyFromApi + ") does not match key retrieved from LAST_INSERT_ID() " + autoIncKeyFromFunc
+                        + ") function", autoIncKeyFromApi == autoIncKeyFromFunc);
+            } else {
+                fail("AutoIncrement keys were '0'");
+            }
+        } finally {
+            if (this.rs != null) {
+                try {
+                    this.rs.close();
+                } catch (Exception ex) {
+                    // ignore
+                }
+            }
+
+            this.rs = null;
         }
     }
 
@@ -778,6 +777,8 @@ public class StatementsTest extends BaseTestCase {
         Statement stmt2 = null;
         PreparedStatement pstmt2 = null;
 
+        ResultSet rs2 = null;
+
         try {
             stmt2 = conn2.createStatement();
 
@@ -806,10 +807,11 @@ public class StatementsTest extends BaseTestCase {
             this.rs = pstmt2.executeQuery();
             this.rs.next();
             this.rs.getInt(1);
-            pstmt2.executeQuery();
+            rs2 = pstmt2.executeQuery();
             this.rs.getInt(1);
             pstmt2.execute();
             this.rs.getInt(1);
+            rs2.close();
 
             pstmt2 = ((com.mysql.jdbc.Connection) conn2).clientPrepareStatement("SELECT 1");
             this.rs = pstmt2.executeQuery();
@@ -822,16 +824,17 @@ public class StatementsTest extends BaseTestCase {
             this.rs = pstmt2.executeQuery();
             this.rs.next();
             this.rs.getInt(1);
-            pstmt2.executeQuery();
+            rs2 = pstmt2.executeQuery();
             this.rs.getInt(1);
             pstmt2.execute();
             this.rs.getInt(1);
+            rs2.close();
 
             stmt2 = conn2.createStatement();
             this.rs = stmt2.executeQuery("SELECT 1");
             this.rs.next();
             this.rs.getInt(1);
-            stmt2.executeQuery("SELECT 2");
+            rs2 = stmt2.executeQuery("SELECT 2");
             this.rs.getInt(1);
             this.rs = stmt2.executeQuery("SELECT 1");
             this.rs.next();
@@ -840,6 +843,7 @@ public class StatementsTest extends BaseTestCase {
             this.rs.getInt(1);
             stmt2.execute("SET @var=2");
             this.rs.getInt(1);
+            rs2.close();
         } finally {
             if (stmt2 != null) {
                 stmt2.close();
@@ -864,7 +868,7 @@ public class StatementsTest extends BaseTestCase {
             // Test running a update for an query. It should fail.
             try {
                 this.conn.setAutoCommit(false);
-                this.stmt.executeQuery("UPDATE statement_test SET strdata1='blah' WHERE 1=0");
+                this.rs = this.stmt.executeQuery("UPDATE statement_test SET strdata1='blah' WHERE 1=0");
             } catch (SQLException sqlEx) {
                 assertTrue("Exception thrown for unknown reason", sqlEx.getSQLState().equalsIgnoreCase(SQLError.SQL_STATE_ILLEGAL_ARGUMENT));
             } finally {
@@ -876,28 +880,26 @@ public class StatementsTest extends BaseTestCase {
                 assertTrue("Update count must be '1', was '" + updateCount + "'", (updateCount == 1));
             }
 
-            if (!isRunningOnJdk131()) {
-                int insertIdFromGeneratedKeys = Integer.MIN_VALUE;
+            int insertIdFromGeneratedKeys = Integer.MIN_VALUE;
 
-                this.stmt.executeUpdate("INSERT INTO statement_test (strdata1, strdata2) values ('a', 'a'), ('b', 'b'), ('c', 'c')",
-                        Statement.RETURN_GENERATED_KEYS);
-                this.rs = this.stmt.getGeneratedKeys();
+            this.stmt.executeUpdate("INSERT INTO statement_test (strdata1, strdata2) values ('a', 'a'), ('b', 'b'), ('c', 'c')",
+                    Statement.RETURN_GENERATED_KEYS);
+            this.rs = this.stmt.getGeneratedKeys();
 
-                if (this.rs.next()) {
-                    insertIdFromGeneratedKeys = this.rs.getInt(1);
-                }
-
-                this.rs.close();
-                this.rs = this.stmt.executeQuery("SELECT LAST_INSERT_ID()");
-
-                int insertIdFromServer = Integer.MIN_VALUE;
-
-                if (this.rs.next()) {
-                    insertIdFromServer = this.rs.getInt(1);
-                }
-
-                assertEquals(insertIdFromGeneratedKeys, insertIdFromServer);
+            if (this.rs.next()) {
+                insertIdFromGeneratedKeys = this.rs.getInt(1);
             }
+
+            this.rs.close();
+            this.rs = this.stmt.executeQuery("SELECT LAST_INSERT_ID()");
+
+            int insertIdFromServer = Integer.MIN_VALUE;
+
+            if (this.rs.next()) {
+                insertIdFromServer = this.rs.getInt(1);
+            }
+
+            assertEquals(insertIdFromGeneratedKeys, insertIdFromServer);
         } finally {
             if (this.rs != null) {
                 try {
@@ -1101,7 +1103,7 @@ public class StatementsTest extends BaseTestCase {
                 assertEquals(3, this.rs.getInt(1));
                 assertEquals(false, this.rs.next());
 
-                fetchStmt.executeQuery();
+                this.rs = fetchStmt.executeQuery();
             } finally {
                 if (fetchConn != null) {
                     fetchConn.close();
@@ -1193,14 +1195,11 @@ public class StatementsTest extends BaseTestCase {
             multiStmt.addBatch("UPDATE testStatementRewriteBatch SET field1=6 WHERE field1=2 OR field1=3");
 
             int[] counts = multiStmt.executeBatch();
+            ResultSet genKeys = multiStmt.getGeneratedKeys();
 
-            if (!isRunningOnJdk131()) {
-                ResultSet genKeys = multiStmt.getGeneratedKeys();
-
-                for (int i = 1; i < 5; i++) {
-                    genKeys.next();
-                    assertEquals(i, genKeys.getInt(1));
-                }
+            for (int i = 1; i < 5; i++) {
+                genKeys.next();
+                assertEquals(i, genKeys.getInt(1));
             }
 
             assertEquals(counts.length, 6);
@@ -1233,14 +1232,11 @@ public class StatementsTest extends BaseTestCase {
             }
 
             multiStmt.executeBatch();
+            genKeys = multiStmt.getGeneratedKeys();
 
-            if (!isRunningOnJdk131()) {
-                ResultSet genKeys = multiStmt.getGeneratedKeys();
-
-                for (int i = 1; i < 1000; i++) {
-                    genKeys.next();
-                    assertEquals(i, genKeys.getInt(1));
-                }
+            for (int i = 1; i < 1000; i++) {
+                genKeys.next();
+                assertEquals(i, genKeys.getInt(1));
             }
 
             createTable("testStatementRewriteBatch", "(pk_field INT PRIMARY KEY NOT NULL AUTO_INCREMENT, field1 INT)");
@@ -1251,23 +1247,19 @@ public class StatementsTest extends BaseTestCase {
             multiConn = getConnectionWithProps(props);
 
             PreparedStatement pStmt = null;
+            pStmt = multiConn.prepareStatement("INSERT INTO testStatementRewriteBatch(field1) VALUES (?)", Statement.RETURN_GENERATED_KEYS);
 
-            if (!isRunningOnJdk131()) {
-                pStmt = multiConn.prepareStatement("INSERT INTO testStatementRewriteBatch(field1) VALUES (?)", Statement.RETURN_GENERATED_KEYS);
+            for (int i = 0; i < 1000; i++) {
+                pStmt.setInt(1, i);
+                pStmt.addBatch();
+            }
 
-                for (int i = 0; i < 1000; i++) {
-                    pStmt.setInt(1, i);
-                    pStmt.addBatch();
-                }
+            pStmt.executeBatch();
+            genKeys = pStmt.getGeneratedKeys();
 
-                pStmt.executeBatch();
-
-                ResultSet genKeys = pStmt.getGeneratedKeys();
-
-                for (int i = 1; i < 1000; i++) {
-                    genKeys.next();
-                    assertEquals(i, genKeys.getInt(1));
-                }
+            for (int i = 1; i < 1000; i++) {
+                genKeys.next();
+                assertEquals(i, genKeys.getInt(1));
             }
 
             createTable("testStatementRewriteBatch", "(pk_field INT PRIMARY KEY NOT NULL AUTO_INCREMENT, field1 INT)");
@@ -1276,33 +1268,28 @@ public class StatementsTest extends BaseTestCase {
             props.setProperty("maxAllowedPacket", j == 0 ? "10240" : "1024");
             multiConn = getConnectionWithProps(props);
 
-            if (!isRunningOnJdk131()) {
+            pStmt = multiConn.prepareStatement("INSERT INTO testStatementRewriteBatch(field1) VALUES (?)", Statement.RETURN_GENERATED_KEYS);
 
-                pStmt = multiConn.prepareStatement("INSERT INTO testStatementRewriteBatch(field1) VALUES (?)", Statement.RETURN_GENERATED_KEYS);
+            for (int i = 0; i < 1000; i++) {
+                pStmt.setInt(1, i);
+                pStmt.addBatch();
+            }
 
-                for (int i = 0; i < 1000; i++) {
-                    pStmt.setInt(1, i);
-                    pStmt.addBatch();
-                }
+            pStmt.executeBatch();
+            genKeys = pStmt.getGeneratedKeys();
 
-                pStmt.executeBatch();
-
-                ResultSet genKeys = pStmt.getGeneratedKeys();
-
-                for (int i = 1; i < 1000; i++) {
-                    genKeys.next();
-                    assertEquals(i, genKeys.getInt(1));
-                }
+            for (int i = 1; i < 1000; i++) {
+                genKeys.next();
+                assertEquals(i, genKeys.getInt(1));
             }
 
             Object[][] differentTypes = new Object[1000][14];
 
-            createTable("rewriteBatchTypes", "(internalOrder int, f1 tinyint null, "
-                    + "f2 smallint null, f3 int null, f4 bigint null, "
-                    + "f5 decimal(8, 2) null, f6 float null, f7 double null, "
-                    + "f8 varchar(255) null, f9 text null, f10 blob null, f11 blob null, "
-                    + (versionMeetsMinimum(5, 6, 4) ? "f12 datetime(3) null, f13 time(3) null, f14 date null)"
-                            : "f12 datetime null, f13 time null, f14 date null)"));
+            createTable("rewriteBatchTypes",
+                    "(internalOrder int, f1 tinyint null, " + "f2 smallint null, f3 int null, f4 bigint null, "
+                            + "f5 decimal(8, 2) null, f6 float null, f7 double null, " + "f8 varchar(255) null, f9 text null, f10 blob null, f11 blob null, "
+                            + (versionMeetsMinimum(5, 6, 4) ? "f12 datetime(3) null, f13 time(3) null, f14 date null)"
+                                    : "f12 datetime null, f13 time null, f14 date null)"));
 
             for (int i = 0; i < 1000; i++) {
                 differentTypes[i][0] = Math.random() < .5 ? null : new Byte((byte) (Math.random() * 127));
@@ -1325,8 +1312,8 @@ public class StatementsTest extends BaseTestCase {
             props.setProperty("rewriteBatchedStatements", "true");
             props.setProperty("maxAllowedPacket", j == 0 ? "10240" : "1024");
             multiConn = getConnectionWithProps(props);
-            pStmt = multiConn.prepareStatement("INSERT INTO rewriteBatchTypes(internalOrder,f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13,f14) VALUES "
-                    + "(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
+            pStmt = multiConn.prepareStatement(
+                    "INSERT INTO rewriteBatchTypes(internalOrder,f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13,f14) VALUES " + "(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
 
             for (int i = 0; i < 1000; i++) {
                 pStmt.setInt(1, i);
@@ -1363,7 +1350,7 @@ public class StatementsTest extends BaseTestCase {
 
             // We need to format this ourselves, since we have to strip the nanos off of TIMESTAMPs, so .equals() doesn't really work...
 
-            SimpleDateFormat sdf = new SimpleDateFormat("''yyyy-MM-dd HH:mm:ss''", Locale.US);
+            SimpleDateFormat sdf = TimeUtil.getSimpleDateFormat(null, "''yyyy-MM-dd HH:mm:ss''", null, null);
 
             while (this.rs.next()) {
                 for (int k = 0; k < 14; k++) {
@@ -1375,7 +1362,7 @@ public class StatementsTest extends BaseTestCase {
 
                         if (className.equals("java.io.StringReader")) {
                             StringReader reader = (StringReader) differentTypes[idx][k];
-                            StringBuffer buf = new StringBuffer();
+                            StringBuilder buf = new StringBuilder();
 
                             int c = 0;
 
@@ -1412,7 +1399,8 @@ public class StatementsTest extends BaseTestCase {
                         } else if (differentTypes[idx][k] instanceof Timestamp) {
                             assertEquals("On row " + idx + ", column " + (k + 1), sdf.format(differentTypes[idx][k]), sdf.format(this.rs.getObject(k + 1)));
                         } else if (differentTypes[idx][k] instanceof Double) {
-                            assertEquals("On row " + idx + ", column " + (k + 1), ((Double) differentTypes[idx][k]).doubleValue(), this.rs.getDouble(k + 1), .1);
+                            assertEquals("On row " + idx + ", column " + (k + 1), ((Double) differentTypes[idx][k]).doubleValue(), this.rs.getDouble(k + 1),
+                                    .1);
                         } else if (differentTypes[idx][k] instanceof Float) {
                             assertEquals("On row " + idx + ", column " + (k + 1), ((Float) differentTypes[idx][k]).floatValue(), this.rs.getFloat(k + 1), .1);
                         } else if (className.equals("java.lang.Byte")) {
@@ -1575,11 +1563,9 @@ public class StatementsTest extends BaseTestCase {
     }
 
     public void testStubbed() throws SQLException {
-        if (!isRunningOnJdk131()) {
-            try {
-                this.stmt.getResultSetHoldability();
-            } catch (NotImplemented notImplEx) {
-            }
+        try {
+            this.stmt.getResultSetHoldability();
+        } catch (NotImplemented notImplEx) {
         }
     }
 
@@ -1711,7 +1697,7 @@ public class StatementsTest extends BaseTestCase {
 
         try {
             Properties props = new Properties();
-            props.setProperty("statementInterceptors", "com.mysql.jdbc.interceptors.ServerStatusDiffInterceptor");
+            props.setProperty("statementInterceptors", ServerStatusDiffInterceptor.class.getName());
 
             interceptedConn = getConnectionWithProps(props);
             this.rs = interceptedConn.createStatement().executeQuery("SELECT 'abc'");
@@ -1733,7 +1719,7 @@ public class StatementsTest extends BaseTestCase {
                 now // to test serialization
         };
 
-        StringBuffer statementText = new StringBuffer("SELECT ?");
+        StringBuilder statementText = new StringBuilder("SELECT ?");
 
         for (int i = 1; i < valuesToTest.length; i++) {
             statementText.append(",?");
@@ -1750,7 +1736,7 @@ public class StatementsTest extends BaseTestCase {
         for (int i = 0; i < valuesToTest.length; i++) {
             Object boundObject = bindings.getObject(i + 1);
 
-            if (boundObject == null && valuesToTest[i] == null) {
+            if (boundObject == null || valuesToTest[i] == null) {
                 continue;
             }
 
